#
# spec file for package php-gmagick
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    gmagick

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        2.0.6RC1
Release:        4.5
Summary:        Wrapper to the GraphicsMagick library
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/gmagick
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        php-%{pkg_name}-rpmlintrc
Patch1:         ignore-test-GraphicsMagick-1.3.36.patch
# PATCH-FIX-UPSTREAM: https://github.com/vitoc/gmagick/pull/54
Patch2:         fix-param-order-in-test.patch
BuildRequires:  %{php_name}-devel
BuildRequires:  GraphicsMagick-devel
BuildRequires:  ghostscript-fonts-std
BuildRequires:  re2c
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Conflicts:      %{php_name}-imagick
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}

%description
PHP extension to create, modify and obtain meta information of images using
the GraphicsMagick API

%prep
%autosetup -p1 -n %{pkg_name}-%{version}

%build
export CFLAGS="%{optflags} -fvisibility=hidden %(GraphicsMagick-config --cflags)"
%{__phpize}
%configure
%make_build

%check
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%files
%license LICENSE
%doc CONTRIBUTORS.md README.md
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Wed Feb 21 2024 Arjen de Korte <suse+build@de-korte.org>
- Change to %%autosetup as RPM 4.20 will no longer support %%patchN
- Ignore flaky test in all builds
  %% ignore-test-GraphicsMagick-1.3.36.patch
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Thu Jan 27 2022 Arjen de Korte <suse+build@de-korte.org>
- Fix wrong parameter order in test
  + fix-param-order-in-test.patch
* Wed Feb 17 2021 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file via spec-cleaner.
* Tue Feb 16 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
* Thu Feb 11 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 2.0.6RC1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=gmagick&release=2.0.6RC1
  * Works with PHP 8 but some fixes still required.
- Remove fix-segfault-on-shutdown.patch (fixed upstream)
* Fri Jan 22 2021 Arjen de Korte <suse+build@de-korte.org>
- Expect test to fail with GraphicsMagick-1.3.36 (due to API change)
  + ignore-test-GraphicsMagick-1.3.36.patch
* Sun Jan 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use php_cfgdir and php_extdir macros to determine location of files
- Generate .ini file from spec
  - delete imagick.ini
* Sat Jan  4 2020 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file.
* Sat Jan  4 2020 Arjen de Korte <suse+build@de-korte.org>
- Segfaults on shutdown need to be mitigated when GraphicsMagick is
  compiled with OpenMP support and PHP >= 7.4 only. For GCC < 9,
  the only option is to run in single thread mode, for GCC >= 9
  wait until OpenMP has relinquished its resources (modified
  fix-segfault-on-shutdown.patch).
* Sat Dec 28 2019 Arjen de Korte <suse+build@de-korte.org>
- Run in single thread mode by default to prevent a segfault on
  shutdown in PHP 7.4 (fix-segfault-on-shutdown.patch)
* Mon May 14 2018 jweberhofer@weberhofer.at
- Due to a packaging change in ghostscript the ghostscript-fonts-std
  has to be included explicitly to successfully run the tests. Elsewise
  the required helvetica-font is missing. Fix for bnc#1091930.
* Thu May 10 2018 ilya@ilya.pp.ua
- Disable tests, because test fail with php7 7.2.5. (bsc#1091930)
* Fri Mar 16 2018 crrodriguez@opensuse.org
- Build extension with -fvisibility=hidden, to limit
  chance of symbol collisions with other extensions or libraries
  loaded in the same process.
- This extenion conflicts with php7-imagick (boo#1085595)
* Thu Mar  8 2018 ilya@ilya.pp.ua
- Remove %%configure/make duplicates.
- Add %%licence macros.
* Thu Jan  4 2018 ilya@ilya.pp.ua
- Update to 2.0.5RC1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=gmagick&release=2.0.5RC1
  * hasNextImage() and hasPreviousImage() now actually returns TRUE on success instead of Gmagick object.
* Tue Jul 11 2017 jweberhofer@weberhofer.at
- Cleaned up spec
- Updated dependencies
* Mon Jul 10 2017 ilya@ilya.pp.ua
- Initial package for version 2.0.4RC1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=gmagick&release=2.0.4RC1
